@@ -38,6 +38,7 @@ LanMorseForm::LanMorseForm(
     mainWindow(mw),
     morseRunning(false),
     morsePaused(false),
+    runMorseContinuously(false),
     timer(0),
     ui(new Ui::LanMorseForm)
 {
@@ -132,6 +133,25 @@ void LanMorseForm::startE()
 }
 
 
+void LanMorseForm::startSupressLEDs()
+{
+  if (timer)
+  {
+    delete timer;
+    timer = 0;
+  }
+
+  if (morseRunning)
+  {
+    morsePaused = true;
+  }
+
+  timer = new QTimer(this);
+  connect(timer, SIGNAL(timeout()), this, SLOT(runSupressLEDs()));
+  timer->start(ui->dotDurationSpinBox->value());
+}
+
+
 void LanMorseForm::stopTimer()
 {
   if (timer)
@@ -319,6 +339,12 @@ void LanMorseForm::runECode()
 }
 
 
+void LanMorseForm::runSupressLEDs()
+{
+  mainWindow->turnTorchOff();
+}
+
+
 //
 // This method will convert the desired text into morse code bits:
 //
